summaryrefslogtreecommitdiffstats
path: root/bin/g-i-installation.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2014-11-24 00:56:02 +0100
committerHolger Levsen <holger@layer-acht.org>2014-11-24 00:56:02 +0100
commitf63b04ac77fac16d4c223f72eaa4465159eb68de (patch)
tree26d1a3a6096e05329f6c31a2b68b7bead70111eb /bin/g-i-installation.sh
parent9629a0d350077b0d02876e033d6c5f7a8c66ad16 (diff)
downloadjenkins.debian.net-f63b04ac77fac16d4c223f72eaa4465159eb68de.tar.xz
g-i: add three new jobs: (sid_daily|jessie|wheezy)_presentation - Thanks to Phil Hands and Frans Pop
Diffstat (limited to 'bin/g-i-installation.sh')
-rw-r--r--bin/g-i-installation.sh28
1 files changed, 25 insertions, 3 deletions
diff --git a/bin/g-i-installation.sh b/bin/g-i-installation.sh
index 64cb4ade..a33725fa 100644
--- a/bin/g-i-installation.sh
+++ b/bin/g-i-installation.sh
@@ -124,7 +124,7 @@ cleanup_all() {
# save logs if there are any
#
case $NAME in
- *_rescue*) ;;
+ *_rescue*|*_presentation) ;;
*) if [ $NR -gt 200 ] ; then
save_logs
else
@@ -307,6 +307,9 @@ bootstrap_system() {
*_speakup)
EXTRA_APPEND="$EXTRA_APPEND speakup.synth=soft"
;;
+ *_presentation)
+ EXTRA_APPEND="$EXTRA_APPEND url=hands.com classes=talks/fosdem07"
+ ;;
*)
;;
esac
@@ -442,6 +445,21 @@ rescue_boot() {
esac
}
+presentation_boot() {
+ # boot in presentation mode
+ let MY_NR=NR-TRIGGER_NR
+ TOKEN=$(printf "%04d" $MY_NR)
+ case $TOKEN in
+ #0010) do_and_report key tab
+ # ;;
+ #0020) do_and_report key enter
+ # ;;
+ #0100) do_and_report key tab
+ # ;;
+ *) ;;
+ esac
+}
+
post_install_boot() {
# normal boot after installation
let MY_NR=NR-TRIGGER_NR
@@ -1119,6 +1137,8 @@ monitor_system() {
case $MODE in
rescue) rescue_boot
;;
+ presentation) presentation_boot
+ ;;
post_install) post_install_boot
;;
*) ;;
@@ -1273,7 +1293,9 @@ fi
bootstrap_system
set +x
case $NAME in
- *_rescue*) monitor_system rescue
+ *_rescue*) monitor_system rescue
+ ;;
+ *_presentation) monitor_system presentation
;;
debian-edu_*combi-server) monitor_system install wait4match 3000
;;
@@ -1287,7 +1309,7 @@ esac
#
let NR=NR+1
case $NAME in
*_rescue*) # so there are some artifacts to publish
mkdir -p $RESULTS/log/installer
touch $RESULTS/log/dummy $RESULTS/log/installer/dummy
;;
@@ -1287,7 +1309,7 @@ esac
let NR=NR+1
case $NAME in
- *_rescue*) # so there are some artifacts to publish
+ *_rescue*|*_presentation) # so there are some artifacts to publish
mkdir -p $RESULTS/log/installer
touch $RESULTS/log/dummy $RESULTS/log/installer/dummy